@@ -206,7 +206,8 @@ class HWEUpgradeDialog(InternalDialog):
         if datetime.date.today() < HweSupportStatus.consts.HWE_EOL_DATE:
             self.set_desc(_(HweSupportStatus.consts.Messages.HWE_SUPPORT_ENDS))
         else:
-            self.set_desc(_(HweSupportStatus.consts.Messages.HWE_SUPPORT_HAS_ENDED))
+            self.set_desc(
+                _(HweSupportStatus.consts.Messages.HWE_SUPPORT_HAS_ENDED))
         self.add_settings_button()
         self.add_button(_("_Install…"), self.install)
         self.focus_button = self.add_button(Gtk.STOCK_OK,
@@ -215,6 +216,7 @@ class HWEUpgradeDialog(InternalDialog):
     def install(self):
         self.window_main.start_install(hwe_upgrade=True)
 
+
 class UnsupportedDialog(DistUpgradeDialog):
     def __init__(self, window_main, meta_release):
         DistUpgradeDialog.__init__(self, window_main, meta_release)
@@ -324,7 +326,7 @@ class NeedRestartDialog(InternalDialog):
             iface.RequestReboot()
         except dbus.DBusException:
             self._request_reboot_via_consolekit()
-        except:
+        except Exception as e:
             pass
 
     def _request_reboot_via_consolekit(self):
@@ -337,7 +339,7 @@ class NeedRestartDialog(InternalDialog):
             iface.Restart()
         except dbus.DBusException:
             self._request_reboot_via_logind()
-        except:
+        except Exception as e:
             pass
 
     def _request_reboot_via_logind(self):
